@@ -10,6 +10,7 @@ from typing import OrderedDict
 
 from expressmoney.api import PointNotFound404, PointThrottled, PointClientError, PointServerError
 from expressmoney.api.point import PointError
+from requests import JSONDecodeError
 from rest_framework import status
 
 from .client import Request
@@ -62,9 +63,12 @@ class Point:
                     raise PointThrottled(self._client.url, response.status_code, response.headers.get(
                         'Retry-After'))
                 else:
-                    raise PointClientError(self._client.url, response.status_code, response.json())
+                    try:
+                        raise PointClientError(self._client.url, response.status_code, response.json())
+                    except JSONDecodeError:
+                        raise PointServerError(self._client.url, response.status_code, response.text[:128])
             else:
-                raise PointServerError(self._client.url, response.status_code)
+                raise PointServerError(self._client.url, response.status_code, response.text[:128])
 
     def _post_file(self, file):
         self._response = self._client.post_file(file=file)
